==> qtjambi-scxml-6.3.4-sources.jar: io/qt/scxml/QScxmlInvokableService.java <==
package io.qt.scxml;


/**
 * <p>The base class for services called from state machines</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html">QScxmlInvokableService</a></p>
 */
public abstract class QScxmlInvokableService extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableService.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableService {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String id(){
            return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native java.lang.String id_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String name(){
            return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native java.lang.String name_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void postEvent(io.qt.scxml.QScxmlEvent event){
            postEvent_native_QScxmlEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), event);
        }
        @io.qt.QtUninvokable
        private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean start(){
            return start_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean start_native(long __this__nativeId);
        
    }
    
    
    public QScxmlInvokableService(io.qt.scxml.QScxmlStateMachine parentStateMachine, io.qt.scxml.QScxmlInvokableServiceFactory parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parentStateMachine, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableService instance, io.qt.scxml.QScxmlStateMachine parentStateMachine, io.qt.scxml.QScxmlInvokableServiceFactory parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#parentStateMachine-prop">QScxmlInvokableService::parentStateMachine()const</a></p>
     */
    @io.qt.QtPropertyReader(name="parentStateMachine")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.scxml.QScxmlStateMachine parentStateMachine(){
        return parentStateMachine_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlStateMachine parentStateMachine_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#id-prop">QScxmlInvokableService::id()const</a></p>
     */
    @io.qt.QtPropertyReader(name="id")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public abstract java.lang.String id();
    
    @io.qt.QtUninvokable
    private native java.lang.String id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#name-prop">QScxmlInvokableService::name()const</a></p>
     */
    @io.qt.QtPropertyReader(name="name")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public abstract java.lang.String name();
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#postEvent">QScxmlInvokableService::postEvent(QScxmlEvent*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void postEvent(io.qt.scxml.QScxmlEvent event);
    
    @io.qt.QtUninvokable
    private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#start">QScxmlInvokableService::start()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean start();
    
    @io.qt.QtUninvokable
    private native boolean start_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlInvokableService(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-scxml-6.4.2-sources.jar: io/qt/scxml/QScxmlInvokableService.java <==
package io.qt.scxml;


/**
 * <p>The base class for services called from state machines</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html">QScxmlInvokableService</a></p>
 */
public abstract class QScxmlInvokableService extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableService.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableService {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String id(){
            return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native java.lang.String id_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String name(){
            return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native java.lang.String name_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void postEvent(io.qt.scxml.QScxmlEvent event){
            postEvent_native_QScxmlEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), event);
        }
        @io.qt.QtUninvokable
        private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean start(){
            return start_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean start_native(long __this__nativeId);
        
    }
    
    
    public QScxmlInvokableService(io.qt.scxml.QScxmlStateMachine parentStateMachine, io.qt.scxml.QScxmlInvokableServiceFactory parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parentStateMachine, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableService instance, io.qt.scxml.QScxmlStateMachine parentStateMachine, io.qt.scxml.QScxmlInvokableServiceFactory parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#parentStateMachine-prop">QScxmlInvokableService::parentStateMachine()const</a></p>
     */
    @io.qt.QtPropertyReader(name="parentStateMachine")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.scxml.QScxmlStateMachine parentStateMachine(){
        return parentStateMachine_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlStateMachine parentStateMachine_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#id-prop">QScxmlInvokableService::id()const</a></p>
     */
    @io.qt.QtPropertyReader(name="id")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public abstract java.lang.String id();
    
    @io.qt.QtUninvokable
    private native java.lang.String id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#name-prop">QScxmlInvokableService::name()const</a></p>
     */
    @io.qt.QtPropertyReader(name="name")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public abstract java.lang.String name();
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#postEvent">QScxmlInvokableService::postEvent(QScxmlEvent*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void postEvent(io.qt.scxml.QScxmlEvent event);
    
    @io.qt.QtUninvokable
    private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#start">QScxmlInvokableService::start()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean start();
    
    @io.qt.QtUninvokable
    private native boolean start_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlInvokableService(QPrivateConstructor p) { super(p); } 
    
}
